@@ -1,9 +1,48 @@
+$.fn.hasOverflow = function() {
+    var $this = $(this);
+    var $children = $this.find('.tileMedia');
+    var len = $children.length;
+
+    if (len) {
+        var maxWidth = 0;
+        var maxHeight = 0
+        $children.map(function(){
+            maxWidth = Math.max(maxWidth, $(this).outerWidth(true));
+            maxHeight = Math.max(maxHeight, $(this).outerHeight(true));
+        });
+
+        return maxWidth > $this.width() || maxHeight > $this.height();
+    }
+
+    return false;
+};
+
 Arnolfini = {};
 
 Arnolfini.bodyclick = false
 Arnolfini.searchopen = false
 Arnolfini.menuopen = false
 
+Arnolfini.doesBlockOverflow = function (block)
+{
+	var $this = $(block);
+	var $children = $this.find('.tileMedia');
+	var len = $children.length;
+	
+	return len > 3;
+}
+
+Arnolfini.archiveShowButtons = function ()
+{
+	$('.archiveBlocks').each(function ()
+				 {
+					if (Arnolfini.doesBlockOverflow($(this)))
+					{
+						$(this).find('.archiveViewAllButton').show();
+					}
+				})
+}
+
 Arnolfini.events = function ()
 {
 	// show search form on click
@@ -72,4 +111,6 @@ mediaShow.buttonNextContent = "&rarr;";
 
 $(document).ready(function() {
 	Arnolfini.events();
-});
\ No newline at end of file
+	Arnolfini.archiveShowButtons();
+});
+
