@@ -35,7 +35,6 @@ class Assignment(base.Assignment):
     This is what is actually managed through the portlets UI and associated
     with columns.
     """
-
     implements(IYearListPortlet)
 
     @property
@@ -75,10 +74,10 @@ class Renderer(base.Renderer):
             prevYear = currentYear - 1
             nextYear = currentYear +1
             
-            while not self._yearIsDocumented(prevYear) and prevYear > 1900:
+            while not self.yearIsDocumented(prevYear) and prevYear > 1900:
                 prevYear = prevYear - 1
                 
-            while not self._yearIsDocumented(nextYear) and nextYear < 2020:
+            while not self.yearIsDocumented(nextYear) and nextYear < 2020:
                 nextYear = nextYear + 1
             
             if prevYear > 1900:
@@ -105,20 +104,21 @@ class Renderer(base.Renderer):
         end = DateTime(year,12,31) 
         date_range_query = {'query': (start, end), 'range': 'min:max'}
 
-        results = catalog.queryCatalog({"portal_type": "Media Event",
+        if not only_documented:
+            results = catalog.queryCatalog({"portal_type": "Media Event",
                                  "start": date_range_query,
                                  "sort_on": "start",
                                  "sort_order": "reverse",
                                  "review_state": "published"})
-        
-        if not only_documented:
-            return results
         else:
-            filtered = []
-            for event in results:
-                if self._eventIsDocumented(event):
-                    filtered.append(event)
-            return filtered
+            results = catalog.queryCatalog({"portal_type": "Media Event",
+                                 "start": date_range_query,
+                                 "sort_on": "start",
+                                 "sort_order": "reverse",
+                                 "review_state": "published",
+                                 "hasMedia": True})
+        
+        return results
     
     def isCurrentYear(self, year):
         """
@@ -143,7 +143,7 @@ class Renderer(base.Renderer):
         else:
             return desc
 
-    def _yearIsDocumented(self, year):
+    def yearIsDocumented(self, year):
         """
         Checks if a year has any documented events
         """
@@ -162,12 +162,12 @@ class Renderer(base.Renderer):
         
         #go through events until we find one that has docs.
         for event in events:
-            if self._eventIsDocumented(event):
+            if self.eventIsDocumented(event):
                 return True
         
         return False
 
-    def _eventIsDocumented(self, event):
+    def eventIsDocumented(self, event):
         """
         Check if the event has media documentation
         """
